@@ -774,7 +774,7 @@ conboy_note_buffer_backspace_handler(ConboyNoteBuffer *buffer)
 			/* Check if cursor is on the right side of a soft line break. If yes, remove it */
 			prev = start;
 			gtk_text_iter_backward_chars(&prev, 2);
-			if (gtk_text_iter_get_char(&prev) == "\u2028") {
+			if (gtk_text_iter_get_char(&prev) == '\u2028') {
 				GtkTextIter end_break = prev;
 				gtk_text_iter_forward_char(&end_break);
 				gtk_text_buffer_delete(buf, &prev, &end_break);
