@@ -18,10 +18,13 @@
 
 #include "localisation.h"
 
+#include <glib.h>
 #include <gtk/gtk.h>
 #include <tablet-browser-interface.h>
 #include <sys/socket.h>
+#include <stdio.h>
 #include <netinet/in.h>
+#include <string.h>
 
 #include "settings.h"
 #include "json.h"
